==> aroundme_0_5_0.tar.tgz: aroundme_0_5_0/aroundme/language/1/barnraiser_01/report_abuse.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//menu titles
$lang['menu_back'] = 							"back";


//HEADER
$lang['hdr_report_abuse'] = 					"reporting abuse";
$lang['hdr_additional'] = 						"additional information";


//SUBMIT BUTTONS
$lang['sub_report'] = 							"SEND REPORT";


//MAIL AND MESSAGE TEXTS
$lang['mail_subject_abuse_txt'] = 				"aroundme ABUSE REPORT";
$lang['mail_subject_thanks_txt'] = 				"thank you for helping us stop abuse";

//BODY TEXT
$lang['txt_report_txt'] =						"If you have seen any material posted on this site which offends you or which you believe to be illegal you should report it to us. We protect you when you report abuse. You report is sent to the community administrators who will keep your information confidential. They then inform the group administration and the author.<p>The community administrator will send you a message informing you of what action has been taken.</p>";
$lang['txt_page'] =								"page";
$lang['txt_page_txt'] =							"The following page will be sent with your report to the community administrator";
$lang['txt_additional_intro'] =					"When you press the 'SEND REPORT' button we will get informed about the page you were looking at. Please tell us any other information you think may help us.</p>";

?>

==> aroundme_0_6_2.tar.tgz: aroundme_0_6_2/aroundme/language/1/barnraiser_01/report_abuse.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');

//menu titles
$lang['menu_back'] = 							"back";


//HEADER
$lang['hdr_report_abuse'] = 					"reporting abuse";
$lang['hdr_additional'] = 						"additional information";


//SUBMIT BUTTONS
$lang['sub_report'] = 							"SEND REPORT";


//MAIL AND MESSAGE TEXTS
$lang['mail_subject_abuse_txt'] = 				"AROUNDMe ABUSE REPORT";
$lang['mail_subject_thanks_txt'] = 				"thank you for helping us stop abuse";


//BODY TEXT
$lang['txt_report_txt'] =						"If you have seen any material posted on this site which offends you or which you believe to be illegal you should report it to us. We protect you when you report abuse. You report is sent to the community administrators who will keep your information confidential. They then inform the group administration and the author.<p>The community administrator will send you a message informing you of what action has been taken.</p>";
$lang['txt_page'] =								"page";
$lang['txt_page_txt'] =							"The following page will be sent with your report to the community administrator";
$lang['txt_additional_intro'] =					"When you press the 'SEND REPORT' button we will get informed about the page you were looking at. Please tell us any other information you think may help us.</p>";

?>
